<?php
/**
 * @file
 * Allows site builders and administrator to view a module's README file.
 */

/**
 * Implements hook_drush_help().
 */
function readme_drush_help($section) {
  switch ($section) {
    case 'drush:readme-export':
      return dt("Exports a modules README.md file as HTML that can be cut-n-pasted into the modules project page..");
  }
}

/**
 * Implements hook_drush_command().
 */
function readme_drush_command() {
  $items = [];
  $items['readme-export'] = [
    'description' => "Exports a modules README.md file as HTML ",
    'arguments' => [
      'module' => 'Module name.',
    ],
    'examples' => [
      'drush readme-export example' => "Exports example.module's README.txt file as HTML.",
    ],
  ];
  return $items;
}

/**
 * Implements drush_hook_COMMAND_validate().
 */
function drush_readme_export_validate($module = NULL) {
  if (!$module) {
    return drush_set_error(dt('A module name is required.'));
  }

  $path = drupal_get_path('module', $module);
  if (!$path) {
    return drush_set_error(dt("Unable to get '@module' path.", ['@module' => $module]));
  }

  /** @var \Drupal\readme\ReadmeManagerInterface $readme_manager */
  $readme_manager = \Drupal::service('readme.manager');
  if (!$readme_manager->exists($module)) {
    return drush_set_error(dt("Module '@module' does not contain a README file.", ['@module' => $module]));
  }
}

/**
 * Implements drush_hook_COMMAND().
 */
function drush_readme_export($module) {
  /** @var \Drupal\readme\ReadmeManagerInterface $readme_manager */
  $readme_manager = \Drupal::service('readme.manager');
  drush_print('');
  drush_print($readme_manager->getHtml($module));
  drush_print('');
}
